#include "svg01.h"
#include <vector>
#include <iostream>
#include <string>

using namespace std;

void
svg_begin(double width, double height) {
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end() {
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text) {
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";
}

void
svg_rect(double x, double y, double width, double height, string colors_stroke, string colors_fill){
    cout << "<rect x='" << x << "' y='" << y << "' width='" << width << "' height='" << height << "' stroke='" << colors_stroke << "' fill='" << colors_fill << "'/>";
}

void
input_colors(string &colors_stroke, string &colors_fill){
    string color_personal;
    cerr << "Do you want to change colors? Yes/No" << endl;
    cin >> color_personal;
    while ((color_personal != "No") && (color_personal != "Yes")){
        cerr << "WRONG ANSWER! Try again!" << endl;
        cin >> color_personal;
    }
    if (color_personal == "No"){
        return;
    }
    else {
        cerr << "What color for a stroke do you want?" << endl;
        cin >> colors_stroke;
        cerr << "What color to fill do you want?" << endl;
        cin >> colors_fill;
    }
    return;
}

void
show_histogram_svg(const vector<size_t>& bins, string colors_stroke, string colors_fill) {
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;

    svg_begin(IMAGE_WIDTH, IMAGE_HEIGHT);
    double top = 0;
    double maxel = bins[0];
    for (size_t bin : bins) {
        if (maxel > bin){
            maxel = bin;
        }
    }
    for (size_t bin : bins) {
        const double bin_width = (( IMAGE_WIDTH - TEXT_WIDTH ) / BLOCK_WIDTH ) * ( bin / maxel );
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, colors_stroke, colors_fill);
        top += BIN_HEIGHT;
    }
    svg_end();
}



